@@ -1,7 +1,7 @@
 package Proc::Pidfile;
-$Proc::Pidfile::VERSION = '1.08_01'; # TRIAL
+$Proc::Pidfile::VERSION = '1.08_02'; # TRIAL
 
-$Proc::Pidfile::VERSION = '1.0801';use 5.006;
+$Proc::Pidfile::VERSION = '1.0802';use 5.006;
 use strict;
 use warnings;
 
@@ -17,10 +17,9 @@ sub new
     my %args = @_;
     my $self = bless \%args, $class;
 
-    $self->{attempts} = 3 unless defined($self->{attempts});
+    $self->{retries} = 2 unless defined($self->{retries});
 
-    unless ( $self->{pidfile} )
-    {
+    unless ( $self->{pidfile} ) {
         my $basename = basename( $0 );
         my $dir = -w "/var/run" ? "/var/run" : File::Spec->tmpdir();
         croak "Can't write to $dir\n" unless -w $dir;
@@ -108,10 +107,12 @@ sub _create_pidfile
             
             # this might be a race condition, or parallel smoke testers,
             # so we'll back off a random amount of time and try again
-            if ($attempt <= $self->{attempts}) {
+            if ($attempt <= $self->{retries}) {
                 ++$attempt;
                 # TODO: let's try this. Guessing we don't have to
-                #       bother with backoff times
+                #       bother with increasing backoff times
+                my $backoff = 100 + rand(300);
+                $self->_verbose("backing off for $backoff microseconds before trying again");
                 usleep(100 + rand(300));
                 next;
             }
@@ -223,9 +224,46 @@ useful for, for example, cron jobs, where you don't want to create a new
 process if one is already running, but you don't necessarily want to be
 informed of this by cron.
 
+=head2 Retries
+
+If another instance of your script is already running,
+we'll retry a couple of times,
+with a random number of microseconds between each attempt.
+
+You can specify the number of retries, for example if you
+want to try more times for some reason:
+
+ $pidfile = $pp->pidfile(retries => 4);
+
+By default this is set to 2,
+which means if the first attempt to set up a pidfile fails,
+it will try 2 more times, so three attempts in total.
+
+Setting retries to 0 (zero) will disable this feature.
+
+
 =head1 SEE ALSO
 
-L<Proc::PID::File>
+L<Proc::PID::File> - provides a similar interface.
+
+L<PidFile> - provides effectively the same functionality,
+but via class methods. Hasn't been updated since 2011,
+and has quite a few CPAN Testers fails.
+
+L<IPC::Pidfile> - provides a simple interface, but has some restrictions,
+and its documentation even recommends you consider a different module,
+as it has a race condition.
+
+L<IPC::Lockfile> - very simple interface, and uses a different mechanism:
+it tries to lock the script file which used the module.
+The trouble with that is that you might be running someone else's script,
+and thus can't lock it.
+
+L<Sys::RunAlone> - another one with a simple default interface,
+but can be configured to retry. Based on locking, rather than a pid file.
+Doesn't work on Windows.
+
+L<Linux::Pidfile> - Linux-specific solution.
 
 =head1 REPOSITORY
 
